#!/usr/bin/python3
# -*- coding: utf8 -*-


from setuptools import setup, find_packages


setup(
    name = "py-nat",
    version = "1.0.14",
    description = "Basic Library",
    url = "https://github.com/natloc-developer/py-nat.git",

    author = "natloc_developer",
    author_email = "natloc_developer@foxmail.com",

    packages = find_packages(),

    platforms = "any",
)